def distance_haversine_m(lat1: float, lon1: float, lat2: float, lon2: float) -> float:
    """Calculates haversine distance in meters for given 2 points
    Uses this function: https://docs.rs/geo/latest/geo/algorithm/haversine_distance/trait.HaversineDistance.html

    Returns:
        float: distance in meters
    """

def distance_geodesic_m(lat1: float, lon1: float, lat2: float, lon2: float) -> float:
    """Calculates geodesic distance in meters for given 2 points
    Uses this function: https://docs.rs/geo/latest/geo/algorithm/geodesic_distance/trait.GeodesicDistance.html

    Returns:
        float: distance in meters
    """
